# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .failed_operation import FailedOperation


class BulkOperationResponse(UniversalBaseModel):
    """
    Schema for bulk operation response.
    """

    success_count: int = pydantic.Field()
    """
    Number of successful operations
    """

    failure_count: int = pydantic.Field()
    """
    Number of failed operations
    """

    failed_operations: typing.List[FailedOperation] = pydantic.Field()
    """
    Details of failed operations
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
