# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .access_level import AccessLevel


class AccessRightGrantRequest(UniversalBaseModel):
    """
    Request schema for granting access rights.
    """

    user_id: str = pydantic.Field()
    """
    User ID to grant access to
    """

    access_level: AccessLevel = pydantic.Field()
    """
    Access level to grant
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
