# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ToolParameterResponse(UniversalBaseModel):
    """
    Parameter structure for tool configuration.
    """

    name: str = pydantic.Field()
    """
    Parameter name (e.g., 'sources', 'outputs')
    """

    type: str = pydantic.Field()
    """
    Parameter data type (e.g., 'boolean', 'string', 'integer')
    """

    default: typing.Any
    description: str = pydantic.Field()
    """
    Description of what the parameter controls
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
