# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SessionSpeakerDetail(UniversalBaseModel):
    """
    Speaker stats within a single session.
    """

    speaker: str
    speaking_seconds: float
    speaking_percentage: float
    word_count: int
    segment_count: int
    avg_confidence: float
    words_per_minute: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
