# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class LiveInteractionResponse(UniversalBaseModel):
    """
    Response for a single live interaction.
    """

    id: str
    session_id: str
    trigger_channel: str
    trigger_text: str
    extracted_request: str
    sender: typing.Optional[str] = None
    response_text: typing.Optional[str] = None
    response_model: typing.Optional[str] = None
    response_tokens_used: typing.Optional[int] = None
    workflow_execution_id: typing.Optional[str] = None
    latency_ms: typing.Optional[int] = None
    status: str
    error_message: typing.Optional[str] = None
    created_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
