# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SpeakerInfo(UniversalBaseModel):
    """
    Info about a distinct speaker in a session.
    """

    speaker_key: str
    raw_label: str
    display_name: typing.Optional[str] = None
    segment_count: int
    first_text: str
    total_speaking_seconds: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
